<?php

namespace Drupal\wikiloc\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Plugin implementation of the 'Wikiloc' field type.
 *
 * @FieldType(
 *   id = "wikiloc_map_field",
 *   label = @Translation("Wikiloc Map field"),
 *   description = @Translation("This field stores Wikiloc fields in the database."),
 *   default_widget = "wikiloc_map_field_default",
 *   default_formatter = "wikiloc_map_field_default"
 * )
 */
class MapItem extends FieldItemBase {
  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return array(
      'columns' => array(
        'id' => array(
          'type' => 'varchar',
          'length' => 15,
          'not null' => TRUE,
        ),
        'measures' => array(
          'type' => 'varchar',
          'length' => 2,
          'not null' => FALSE,
          'default' => 'on',
        ),
        'near' => array(
          'type' => 'varchar',
          'length' => 2,
          'not null' => FALSE,
          'default' => 'on',
        ),
        'images' => array(
          'type' => 'varchar',
          'length' => 2,
          'not null' => FALSE,
          'default' => 'on',
        ),
        'maptype' => array(
          'type' => 'varchar',
          'length' => 1,
          'not null' => FALSE,
          'default' => 'S',
        ),
        'width' => array(
          'type' => 'varchar',
          'length' => 10,
          'not null' => FALSE,
        ),
        'height' => array(
          'type' => 'varchar',
          'length' => 10,
          'not null' => FALSE,
        ),
      ),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('id')->getValue();
    return $value === NULL || $value === '';
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['id'] = DataDefinition::create('string')
      ->setLabel(t('Id'));
    $properties['measures'] = DataDefinition::create('string')
      ->setLabel(t('Measures'));
    $properties['near'] = DataDefinition::create('string')
      ->setLabel(t('Near'));
    $properties['images'] = DataDefinition::create('string')
      ->setLabel(t('Images'));
    $properties['maptype'] = DataDefinition::create('string')
      ->setLabel(t('Type map'));
    $properties['width'] = DataDefinition::create('string')
      ->setLabel(t('Width'));
    $properties['height'] = DataDefinition::create('string')
      ->setLabel(t('Height'));

    return $properties;
  }

}
